@@ -23,6 +23,8 @@ import numpy as np
 import pandas as pd
 from ecl.eclfile import EclFile
 
+from ecl2df import getLogger_ecl2csv
+
 from .common import merge_zones, write_dframe_stdout_file
 from .eclfiles import EclFiles
 from .gruptree import tree_from_dict
@@ -363,11 +365,11 @@ def split_seg_icd(seg_data: pd.DataFrame) -> pd.DataFrame:
 
     icd_seg_data.columns = ["ICD_" + x for x in icd_seg_data.columns]
 
-    msg = "Found %d ICD segments, indices %s" % (
+    logger.debug(
+        "Found %d ICD segments, indices %s",
         len(icd_seg_data),
         str(icd_seg_data["ICD_SEGIDX"].values),
     )
-    logger.debug(msg)
 
     return (seg_data, icd_seg_data)
 
@@ -534,12 +536,11 @@ def df(
             continue
 
         logger.info(
-            "Extracting {} well {:>8} at {}, record index: {}".format(
-                rftrecord["wellmodel"],
-                rftrecord["wellname"],
-                rftrecord["date"],
-                rftrecord["timeindex"],
-            )
+            "Extracting %s well %s at %s, record index: %s",
+            rftrecord["wellmodel"],
+            str.rjust(rftrecord["wellname"], 8),
+            rftrecord["date"],
+            rftrecord["timeindex"],
         )
 
         headers = rftrecord["headers"]
@@ -673,10 +674,9 @@ def fill_parser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
 
 def rft_main(args) -> None:
     """Entry-point for module, for command line utility"""
-    if args.verbose:
-        logging.basicConfig(level=logging.INFO)
-    if args.debug:
-        logging.basicConfig(level=logging.DEBUG)
+    logger = getLogger_ecl2csv(  # pylint: disable=redefined-outer-name
+        __name__, vars(args)
+    )
     if args.DATAFILE.endswith(".RFT"):
         # Support the RFT file as an argument also:
         eclfiles = EclFiles(args.DATAFILE.replace(".RFT", "") + ".DATA")
