@@ -1,6 +1,5 @@
 """Test module for compdat"""
 
-import sys
 from pathlib import Path
 
 import pandas as pd
@@ -8,8 +7,18 @@ import pytest
 
 from ecl2df import EclFiles, compdat, ecl2csv
 
+try:
+    import opm  # noqa
+except ImportError:
+    pytest.skip(
+        "OPM is not installed",
+        allow_module_level=True,
+    )
+
+
 TESTDIR = Path(__file__).absolute().parent
-DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+REEK = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+EIGHTCELLS = str(TESTDIR / "data/eightcells/EIGHTCELLS.DATA")
 
 SCHFILE = str(TESTDIR / "data/reek/eclipse/include/schedule/reek_history.sch")
 
@@ -22,7 +31,7 @@ SCHFILE_VALV = str(TESTDIR / "data/reek/eclipse/include/schedule/op6_valve1_gp.s
 
 def test_df():
     """Test main dataframe API, only testing that something comes out"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(EIGHTCELLS)
     compdat_df = compdat.df(eclfiles)
     assert not compdat_df.empty
     assert "ZONE" in compdat_df
@@ -32,12 +41,12 @@ def test_df():
 
 def test_comp2df():
     """Test that dataframes are produced"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(EIGHTCELLS)
     compdfs = compdat.deck2dfs(eclfiles.get_ecldeck())
 
     assert not compdfs["COMPDAT"].empty
-    assert compdfs["WELSEGS"].empty  # REEK demo does not include multisegment wells
-    assert compdfs["COMPSEGS"].empty
+    assert not compdfs["WELSEGS"].empty
+    assert not compdfs["COMPSEGS"].empty
     assert not compdfs["COMPDAT"].columns.empty
 
 
@@ -180,57 +189,20 @@ COMPDAT
     assert "2001-05-02" in dates
     assert "2001-05-07" in dates
 
-
-def test_applywelopen():
-    schstr = """
-DATES
-   1 MAY 2001 /
-/
-
+    schstr_nodate = """
 COMPDAT
  'OP1' 33 110 31 31 'OPEN'  /
 /
-WELOPEN
- 'OP1' 'SHUT' /
-/
 
 TSTEP
   1 /
 
 COMPDAT
- 'OP2' 66 110 31 31 'OPEN'  /
+ 'OP1' 34 111 32 32 'OPEN' /
 /
-
-WELOPEN
- 'OP1' 'OPEN' /
-/
-
-TSTEP
-  2 3 /
-
-WELOPEN
- 'OP1' 'POPN' /
- 'OP2' 'SHUT' /
-/
-"""
-    df = compdat.deck2dfs(EclFiles.str2deck(schstr))["COMPDAT"]
-    assert df.shape[0] == 5
-    assert df["OP/SH"].nunique() == 2
-    assert df["DATE"].nunique() == 3
-
-    schstr = """
-DATES
-   1 MAY 2001 /
-/
-
-COMPDAT
- 'OP1' 33 110 31 31 'OPEN'  /
-/
-WELOPEN
- 'OP2' 'SHUT' /
-/"""
-    with pytest.raises(ValueError):
-        compdat.deck2dfs(EclFiles.str2deck(schstr))["COMPDAT"]
+    """
+    assert compdat.deck2dfs(EclFiles.str2deck(schstr_nodate)) == {}
+    # (critical error logged)
 
 
 def test_unrollcompdatk1k2():
@@ -294,7 +266,7 @@ def test_unrollbogus():
 
 def test_initmerging():
     """Test that we can ask for INIT vectors to be merged into the data"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     noinit_df = compdat.df(eclfiles)
     df = compdat.df(eclfiles, initvectors=[])
     assert isinstance(df, pd.DataFrame)
@@ -314,10 +286,12 @@ def test_initmerging():
         compdat.df(eclfiles, initvectors=2)
 
 
-def test_main_subparsers(tmpdir):
+def test_main_subparsers(tmp_path, mocker):
     """Test command line interface"""
-    tmpcsvfile = tmpdir / "compdat.csv"
-    sys.argv = ["ecl2csv", "compdat", "-v", DATAFILE, "-o", str(tmpcsvfile)]
+    tmpcsvfile = tmp_path / "compdat.csv"
+    mocker.patch(
+        "sys.argv", ["ecl2csv", "compdat", "-v", EIGHTCELLS, "-o", str(tmpcsvfile)]
+    )
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -325,15 +299,18 @@ def test_main_subparsers(tmpdir):
     assert "ZONE" in disk_df
     assert not disk_df.empty
 
-    sys.argv = [
-        "ecl2csv",
-        "compdat",
-        DATAFILE,
-        "--initvectors",
-        "FIPNUM",
-        "-o",
-        str(tmpcsvfile),
-    ]
+    mocker.patch(
+        "sys.argv",
+        [
+            "ecl2csv",
+            "compdat",
+            EIGHTCELLS,
+            "--initvectors",
+            "FIPNUM",
+            "-o",
+            str(tmpcsvfile),
+        ],
+    )
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -341,16 +318,19 @@ def test_main_subparsers(tmpdir):
     assert "FIPNUM" in disk_df
     assert not disk_df.empty
 
-    sys.argv = [
-        "ecl2csv",
-        "compdat",
-        DATAFILE,
-        "--initvectors",
-        "FIPNUM",
-        "EQLNUM",
-        "-o",
-        str(tmpcsvfile),
-    ]
+    mocker.patch(
+        "sys.argv",
+        [
+            "ecl2csv",
+            "compdat",
+            EIGHTCELLS,
+            "--initvectors",
+            "FIPNUM",
+            "EQLNUM",
+            "-o",
+            str(tmpcsvfile),
+        ],
+    )
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -360,7 +340,7 @@ def test_main_subparsers(tmpdir):
     assert not disk_df.empty
 
 
-def test_defaulted_compdat_i_j(tmpdir):
+def test_defaulted_compdat_i_j(tmp_path):
     """I and J can be defaulted (that is 1* or 0) in COMPDAT records, then
     that information should be fetched from the most recent WELSPECS keyword
     """
@@ -370,10 +350,15 @@ WELSPECS
   OP1 OPWEST 20 30 1000 /
 /
 """
-    compdat_str = """
+    compdat_str_def_i = """
 COMPDAT
   'OP1' 1* 0 10 11  /
 /
+"""
+    compdat_str_def_j = """
+COMPDAT
+  'OP1' 20 1* 10 11  /
+/
 """
     compdat_str_nodefaults = """
 COMPDAT
@@ -381,15 +366,30 @@ COMPDAT
 /
 """
 
-    with pytest.raises(ValueError, match="WELSPECS must be provided"):
-        compdat.deck2dfs(EclFiles.str2deck(compdat_str))["COMPDAT"]
+    with pytest.raises(ValueError, match="WELSPECS must be provided when I"):
+        compdat.deck2dfs(EclFiles.str2deck(compdat_str_def_i))["COMPDAT"]
+
+    # I value of 0 also means defaulted:
+    with pytest.raises(ValueError, match="WELSPECS must be provided when I"):
+        compdat.deck2dfs(EclFiles.str2deck(compdat_str_def_i.replace("1*", "0")))[
+            "COMPDAT"
+        ]
+
+    with pytest.raises(ValueError, match="WELSPECS must be provided when J"):
+        compdat.deck2dfs(EclFiles.str2deck(compdat_str_def_j))["COMPDAT"]
+
+    # J value of 0 also means defaulted:
+    with pytest.raises(ValueError, match="WELSPECS must be provided when J"):
+        compdat.deck2dfs(EclFiles.str2deck(compdat_str_def_j.replace("1*", "0")))[
+            "COMPDAT"
+        ]
 
     with pytest.raises(ValueError, match="WELSPECS must be provided"):
         # Wrong order:
-        compdat.deck2dfs(EclFiles.str2deck(compdat_str + welspecs_str))["COMPDAT"]
+        compdat.deck2dfs(EclFiles.str2deck(compdat_str_def_i + welspecs_str))["COMPDAT"]
 
     # Simplest example:
-    compdat_df = compdat.deck2dfs(EclFiles.str2deck(welspecs_str + compdat_str))[
+    compdat_df = compdat.deck2dfs(EclFiles.str2deck(welspecs_str + compdat_str_def_i))[
         "COMPDAT"
     ]
     assert compdat_df["I"].unique() == [20]
@@ -400,13 +400,13 @@ COMPDAT
         EclFiles.str2deck(
             welspecs_str.replace("OP1", "OP2").replace("30", "99")
             + welspecs_str
-            + compdat_str
+            + compdat_str_def_i
         )
     )["COMPDAT"]
 
     # Partial defaulting
     compdat_df = compdat.deck2dfs(
-        EclFiles.str2deck(welspecs_str + compdat_str + compdat_str_nodefaults)
+        EclFiles.str2deck(welspecs_str + compdat_str_def_i + compdat_str_nodefaults)
     )["COMPDAT"]
 
     assert set(compdat_df["I"].unique()) == {20, 55}
@@ -416,8 +416,8 @@ COMPDAT
         EclFiles.str2deck(
             welspecs_str.replace("OP1", "OP2").replace("30", "99")
             + welspecs_str
-            + compdat_str
-            + compdat_str.replace("OP1", "OP2")
+            + compdat_str_def_i
+            + compdat_str_def_i.replace("OP1", "OP2")
         )
     )["COMPDAT"]
 
@@ -431,10 +431,10 @@ COMPDAT
         EclFiles.str2deck(
             "DATES\n  1 JAN 2030 /\n/\n"
             + welspecs_str
-            + compdat_str
+            + compdat_str_def_i
             + "DATES\n  1 JAN 2040 /\n/\n"
             + welspecs_str.replace("30", "33")
-            + compdat_str
+            + compdat_str_def_i
         )
     )["COMPDAT"]
     assert compdat_df[compdat_df["DATE"].astype(str) == "2030-01-01"]["J"].unique() == [
