@@ -1,5 +1,6 @@
 """Test module for equil2df"""
 
+import os
 import subprocess
 from pathlib import Path
 
@@ -10,13 +11,23 @@ import pytest
 from ecl2df import csv2ecl, ecl2csv, equil
 from ecl2df.eclfiles import EclFiles
 
+try:
+    import opm  # noqa
+except ImportError:
+    pytest.skip(
+        "OPM is not installed, nothing relevant in here then",
+        allow_module_level=True,
+    )
+
+
 TESTDIR = Path(__file__).absolute().parent
-DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+REEK = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+EIGHTCELLS = str(TESTDIR / "data/eightcells/EIGHTCELLS.DATA")
 
 
 def test_equil2df():
     """Test that dataframes are produced"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     equildf = equil.df(eclfiles)
     expected = {}
     expected["EQUIL"] = pd.DataFrame(
@@ -70,10 +81,10 @@ def test_equil2df():
     pd.testing.assert_frame_equal(equildf, df_from_inc, check_dtype=False)
 
 
-def test_df2ecl(tmpdir):
+def test_df2ecl(tmp_path):
     """Test that we can write include files to disk"""
-    tmpdir.chdir()
-    eclfiles = EclFiles(DATAFILE)
+    os.chdir(tmp_path)
+    eclfiles = EclFiles(EIGHTCELLS)
     equildf = equil.df(eclfiles)
     equil.df2ecl(equildf, filename="equil.inc")
     assert Path("equil.inc").is_file()
@@ -83,7 +94,7 @@ def test_df2ecl(tmpdir):
     assert Path("eclipse/include/equil.inc").is_file()
 
 
-def test_df2ecl_equil(tmpdir):
+def test_df2ecl_equil(tmp_path):
     """Test the underlying function directly"""
     dframe = pd.DataFrame(
         [
@@ -416,10 +427,10 @@ PDVD
     pd.testing.assert_frame_equal(pdvd_df.drop("KEYWORD", axis="columns"), pdvd_df2)
 
 
-def test_rsvd_via_file(tmpdir, mocker):
+def test_rsvd_via_file(tmp_path, mocker):
     """Test that we can reparse RSVD with unknown TABDIMS
     from a file using the command line utility"""
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     deckstr = """
 RSVD
  10 100
@@ -526,11 +537,11 @@ def test_eclipse_rounding(somefloat, expected):
     assert expected in equil.df2ecl(dframe, withphases=False)
 
 
-def test_main_subparser(tmpdir, mocker, capsys):
+def test_main_subparser(tmp_path, mocker, capsys):
     """Test command line interface"""
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     tmpcsvfile = "equil.csv"
-    mocker.patch("sys.argv", ["ecl2csv", "equil", "-v", DATAFILE, "-o", tmpcsvfile])
+    mocker.patch("sys.argv", ["ecl2csv", "equil", "-v", REEK, "-o", tmpcsvfile])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
