@@ -1,19 +1,19 @@
 import datetime
-import logging
 import os
-import sys
 from datetime import datetime as dt
 from pathlib import Path
 
 import ecl
 import numpy as np
 import pandas as pd
+import pyarrow
 import pytest
 import yaml
 
 from ecl2df import csv2ecl, ecl2csv, summary
 from ecl2df.eclfiles import EclFiles
 from ecl2df.summary import (
+    _df2pyarrow,
     _fallback_date_roll,
     _fix_dframe_for_libecl,
     date_range,
@@ -23,15 +23,21 @@ from ecl2df.summary import (
     smry_meta,
 )
 
-TESTDIR = Path(__file__).absolute().parent
-DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+try:
+    import opm  # noqa
 
-logging.basicConfig(level=logging.INFO)
+    HAVE_OPM = True
+except ImportError:
+    HAVE_OPM = False
+
+TESTDIR = Path(__file__).absolute().parent
+REEK = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+EIGHTCELLS = str(TESTDIR / "data/eightcells/EIGHTCELLS.DATA")
 
 
 def test_df():
     """Test that dataframes are produced"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(EIGHTCELLS)
     sumdf = summary.df(eclfiles)
 
     assert sumdf.index.name == "DATE"
@@ -55,7 +61,7 @@ def test_df():
 
 def test_df_column_keys():
     """Test that we can slice the dataframe on columns"""
-    sumdf = summary.df(EclFiles(DATAFILE), column_keys="FOPT")
+    sumdf = summary.df(EclFiles(REEK), column_keys="FOPT")
     assert set(sumdf.columns) == {"FOPT"}
     assert set(sumdf.attrs["meta"].keys()) == {"FOPT"}
 
@@ -70,25 +76,26 @@ def test_df_column_keys():
         "FOPTF",
         "FOPP",
     }
-    sumdf = summary.df(EclFiles(DATAFILE), column_keys="FOP*")
+    sumdf = summary.df(EclFiles(REEK), column_keys="FOP*")
     assert set(sumdf.columns) == fop_cols
     assert set(sumdf.attrs["meta"].keys()) == fop_cols
 
-    sumdf = summary.df(EclFiles(DATAFILE), column_keys=["FOP*"])
+    sumdf = summary.df(EclFiles(REEK), column_keys=["FOP*"])
     assert set(sumdf.columns) == fop_cols
     assert set(sumdf.attrs["meta"].keys()) == fop_cols
 
-    sumdf = summary.df(EclFiles(DATAFILE), column_keys=["FOPR", "FOPT"])
+    sumdf = summary.df(EclFiles(REEK), column_keys=["FOPR", "FOPT"])
     assert set(sumdf.columns) == {"FOPT", "FOPR"}
     assert set(sumdf.attrs["meta"].keys()) == {"FOPT", "FOPR"}
 
-    with pytest.raises(ValueError, match="No valid key"):
-        summary.df(EclFiles(DATAFILE), column_keys=["BOGUS"])
+    sumdf_no_columns = summary.df(EclFiles(REEK), column_keys=["BOGUS"])
+    assert sumdf_no_columns.columns.empty
+    assert all(sumdf_no_columns.index == sumdf.index)
 
 
 def test_summary2df_dates():
     """Test that we have some API possibilities with ISO dates"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
 
     sumdf = summary.df(
         eclfiles,
@@ -116,42 +123,48 @@ def test_summary2df_dates():
 
 
 @pytest.mark.integration
-def test_ecl2csv_summary(tmpdir):
+def test_ecl2csv_summary(tmp_path, mocker):
     """Test that the command line utility ecl2csv is installed and
     works with summary data"""
-    tmpcsvfile = tmpdir / "sum.csv"
-    sys.argv = [
-        "ecl2csv",
-        "summary",
-        "-v",
-        DATAFILE,
-        "-o",
-        str(tmpcsvfile),
-        "--start_date",
-        "2002-01-02",
-        "--end_date",
-        "2003-01-02",
-    ]
+    tmpcsvfile = tmp_path / "sum.csv"
+    mocker.patch(
+        "sys.argv",
+        [
+            "ecl2csv",
+            "summary",
+            "-v",
+            REEK,
+            "-o",
+            str(tmpcsvfile),
+            "--start_date",
+            "2002-01-02",
+            "--end_date",
+            "2003-01-02",
+        ],
+    )
     ecl2csv.main()
     disk_df = pd.read_csv(tmpcsvfile)
     assert len(disk_df) == 97  # Includes timestamps
     assert str(disk_df["DATE"].values[0]) == "2002-01-02 00:00:00"
     assert str(disk_df["DATE"].values[-1]) == "2003-01-02 00:00:00"
 
-    tmpcsvfile = tmpdir / "sum.csv"
-    sys.argv = [
-        "ecl2csv",
-        "summary",
-        DATAFILE,
-        "-o",
-        str(tmpcsvfile),
-        "--time_index",
-        "daily",
-        "--start_date",
-        "2002-01-02",
-        "--end_date",
-        "2003-01-02",
-    ]
+    tmpcsvfile = tmp_path / "sum.csv"
+    mocker.patch(
+        "sys.argv",
+        [
+            "ecl2csv",
+            "summary",
+            REEK,
+            "-o",
+            str(tmpcsvfile),
+            "--time_index",
+            "daily",
+            "--start_date",
+            "2002-01-02",
+            "--end_date",
+            "2003-01-02",
+        ],
+    )
     ecl2csv.main()
     disk_df = pd.read_csv(tmpcsvfile)
     assert len(disk_df) == 366
@@ -161,7 +174,7 @@ def test_ecl2csv_summary(tmpdir):
     assert str(disk_df["DATE"].values[-1]) == "2003-01-02"
 
 
-def test_paramsupport(tmpdir):
+def test_paramsupport(tmp_path, mocker):
     """Test that we can merge in parameters.txt
 
     This test code manipulates the paths in the checked out
@@ -169,15 +182,17 @@ def test_paramsupport(tmpdir):
     It should not leave any extra files around, but requires certain filenames
     not to be under version control.
     """
-    tmpcsvfile = tmpdir / "sum.csv"
+    tmpcsvfile = tmp_path / "sum.csv"
 
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(EIGHTCELLS)
 
     parameterstxt = Path(eclfiles.get_path()) / "parameters.txt"
     if parameterstxt.is_file():
         parameterstxt.unlink()
     parameterstxt.write_text("FOO 1\nBAR 3", encoding="utf-8")
-    sys.argv = ["ecl2csv", "summary", DATAFILE, "-o", str(tmpcsvfile), "-p"]
+    mocker.patch(
+        "sys.argv", ["ecl2csv", "summary", EIGHTCELLS, "-o", str(tmpcsvfile), "-p"]
+    )
     ecl2csv.main()
     disk_df = pd.read_csv(tmpcsvfile)
     assert "FOPT" in disk_df
@@ -190,7 +205,9 @@ def test_paramsupport(tmpdir):
     if parametersyml.is_file():
         parametersyml.unlink()
     parametersyml.write_text(yaml.dump({"FOO": 1, "BAR": 3}), encoding="utf-8")
-    sys.argv = ["ecl2csv", "summary", DATAFILE, "-o", str(tmpcsvfile), "-p"]
+    mocker.patch(
+        "sys.argv", ["ecl2csv", "summary", EIGHTCELLS, "-o", str(tmpcsvfile), "-p"]
+    )
     ecl2csv.main()
     disk_df = pd.read_csv(str(tmpcsvfile))
     assert "FOPT" in disk_df
@@ -222,10 +239,56 @@ def test_paramsupport(tmpdir):
     parametersyml.unlink()
 
 
-def test_main_subparser(tmpdir):
-    """Test command line interface"""
-    tmpcsvfile = tmpdir / "sum.csv"
-    sys.argv = ["ecl2csv", "summary", DATAFILE, "-o", str(tmpcsvfile)]
+def test_paramsupport_explicitfile(tmp_path, mocker):
+    """Test explicit naming of parameters file from command line.
+
+    This is a little bit tricky because the parameter file is assumed to be
+    relative to the DATA file, not to working directory unless it is absolute."""
+
+    tmpcsvfile = tmp_path / "smrywithrandomparams.txt"
+    randomparamfile = tmp_path / "fooparams.txt"
+    randomparamfile.write_text("FOO barrbarr\nCOM 1234", encoding="ascii")
+    mocker.patch(
+        "sys.argv",
+        [
+            "ecl2csv",
+            "summary",
+            "--verbose",
+            EIGHTCELLS,
+            "-o",
+            str(tmpcsvfile),
+            "--paramfile",
+            str(randomparamfile),  # Absolute filepath
+        ],
+    )
+    ecl2csv.main()
+    assert pd.read_csv(tmpcsvfile)["FOO"].unique() == ["barrbarr"]
+    assert pd.read_csv(tmpcsvfile)["COM"].unique() == [1234]
+
+    # If we now change to tmp_path and give a relative filename to the parameter file,'
+    # it will not be found:
+    os.chdir(tmp_path)
+    mocker.patch(
+        "sys.argv",
+        [
+            "ecl2csv",
+            "summary",
+            "--verbose",
+            EIGHTCELLS,
+            "-o",
+            "smry_noparams.csv",
+            "--paramfile",
+            Path(randomparamfile).name,  # A relative filepath
+        ],
+    )
+    ecl2csv.main()
+    assert "FOO" not in pd.read_csv("smry_noparams.csv")
+
+
+def test_main_subparser(tmp_path, mocker):
+    """Test command line interface with output to both CSV and arrow/feather."""
+    tmpcsvfile = tmp_path / "sum.csv"
+    mocker.patch("sys.argv", ["ecl2csv", "summary", EIGHTCELLS, "-o", str(tmpcsvfile)])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -233,12 +296,38 @@ def test_main_subparser(tmpdir):
     assert not disk_df.empty
     assert "FOPT" in disk_df
 
+    # Test arrow output format:
+    tmparrowfile = tmp_path / "sum.arrow"
+    mocker.patch(
+        "sys.argv",
+        ["ecl2csv", "summary", "--arrow", EIGHTCELLS, "-o", str(tmparrowfile)],
+    )
+    ecl2csv.main()
+    assert Path(tmpcsvfile).is_file()
+    disk_arraydf = pyarrow.feather.read_table(tmparrowfile).to_pandas()
+    assert "FOPT" in disk_arraydf
+
+    # Alternative and equivalent command line syntax for arrow output:
+    tmparrowfile_alt = tmp_path / "sum2.arrow"
+    mocker.patch(
+        "sys.argv", ["ecl2arrow", "summary", EIGHTCELLS, "-o", str(tmparrowfile_alt)]
+    )
+    ecl2csv.main()
+    pd.testing.assert_frame_equal(
+        disk_arraydf, pyarrow.feather.read_table(str(tmparrowfile_alt)).to_pandas()
+    )
+
+    # Not possible (yet?) to write arrow to stdout:
+    mocker.patch("sys.argv", ["ecl2arrow", "summary", EIGHTCELLS, "-o", "-"])
+    with pytest.raises(SystemExit):
+        ecl2csv.main()
+
 
 def test_datenormalization():
     """Test normalization of dates, where
     dates can be ensured to be on dategrid boundaries"""
     # realization-0 here has its last summary date at 2003-01-02
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     daily = summary.df(eclfiles, column_keys="FOPT", time_index="daily", datetime=True)
     assert str(daily.index[-1])[0:10] == "2003-01-02"
     monthly = summary.df(
@@ -254,7 +343,7 @@ def test_datenormalization():
 def test_extrapolation():
     """Summary data should be possible to extrapolate into
     the future, rates should be zero, cumulatives should be constant"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(EIGHTCELLS)
     lastfopt = summary.df(
         eclfiles, column_keys="FOPT", time_index="last", datetime=True
     )["FOPT"].values[0]
@@ -300,11 +389,11 @@ def test_extrapolation():
     )["FOPT"].values == [lastfopt]
 
 
-def test_foreseeable_future(tmpdir):
+def test_foreseeable_future(tmp_path):
     """The foreseeable future in reservoir simulation is "defined" as 500 years.
 
     Check that we support summary files with this timespan"""
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     src_dframe = pd.DataFrame(
         [
             {"DATE": "2000-01-01", "FPR": 200},
@@ -530,7 +619,7 @@ def test_date_range(start, end, freq, expected):
 def test_resample_smry_dates():
     """Test resampling of summary dates"""
 
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
 
     ecldates = eclfiles.get_eclsum().dates
 
@@ -691,7 +780,7 @@ def test_resample_smry_dates():
 
 def test_smry_meta():
     """Test obtaining metadata dictionary for summary vectors from an EclSum object"""
-    meta = smry_meta(EclFiles(DATAFILE))
+    meta = smry_meta(EclFiles(REEK))
 
     assert isinstance(meta, dict)
     assert "FOPT" in meta
@@ -933,9 +1022,115 @@ def test_df2eclsum_datetimeindex():
     assert roundtrip["FOPT"].values == [1000]
 
 
-def test_ecl2df_errors(tmpdir):
+def test_duplicated_summary_vectors(caplog):
+    """EclSum files on disk may contain repeated vectors
+    if the user has inserted a vector name twice in the
+    SUMMARY section
+
+    ecl2df.summary.df() should deduplicate this, and give a warning.
+    """
+
+    # ecl2df.df2eclsum() is not able to mock such a UNSMRY file.
+    dupe_datafile = (
+        TESTDIR
+        / "data"
+        / "eightcells"
+        / "eightcells_duplicated_summary_vector"
+        / "EIGHTCELLS_DUPES.DATA"
+    )
+    assert "SUMMARY\nFOPR\nFOPR" in dupe_datafile.read_text()
+    deduplicated_dframe = df(EclFiles(dupe_datafile))
+    assert (deduplicated_dframe.columns == ["YEARS", "FOPR"]).all()
+    assert "Duplicated columns detected" in caplog.text
+
+
+def test_df2pyarrow_ints():
+    """Test a dummy integer table converted into PyArrow"""
+    dframe = pd.DataFrame(columns=["FOO", "BAR"], data=[[1, 2], [3, 4]]).astype("int32")
+    pyat_df = _df2pyarrow(dframe).to_pandas()
+
+    pd.testing.assert_frame_equal(dframe, pyat_df[["FOO", "BAR"]])
+
+    # Millisecond datetimes:
+    assert (
+        pyat_df["DATE"].to_numpy()
+        == [
+            np.datetime64("1970-01-01T00:00:00.000000000"),
+            np.datetime64("1970-01-01T00:00:00.001000000"),  # Milliseconds
+        ]
+    ).all()
+
+
+def test_df2pyarrow_mix_int_float():
+    """Test that mixed integer and float columns are conserved"""
+    dframe = pd.DataFrame(columns=["FOO", "BAR"], data=[[1, 2], [3, 4]]).astype("int32")
+    dframe["BAR"] *= 1.1  # Make it into a float type.
+    pyat_df = _df2pyarrow(dframe).to_pandas()
+
+    # For the comparison:
+    dframe["BAR"] = dframe["BAR"].astype("float32")
+
+    pd.testing.assert_frame_equal(dframe, pyat_df[["FOO", "BAR"]])
+
+
+def test_df2pyarrow_500years():
+    """Summary files can have DATE columns with timespans outside the
+    Pandas dataframe nanosecond limitation. This should not present
+    a problem to the PyArrow conversion"""
+    dateindex = [dt(1000, 1, 1, 0, 0, 0), dt(3000, 1, 1, 0, 0, 0)]
+    dframe = pd.DataFrame(
+        columns=["FOO", "BAR"], index=dateindex, data=[[1, 2], [3, 4]]
+    ).astype("int32")
+
+    # The index name should be ignored:
+    dframe.index.name = "BOGUS"
+    pyat = _df2pyarrow(dframe)
+
+    with pytest.raises(pyarrow.lib.ArrowInvalid):
+        # We cannot convert this back to Pandas, since it will bail on failing
+        # to use nanosecond timestamps in the dataframe object for these dates.
+        # This is maybe a PyArrow bug/limitation that we must be aware of.
+        pyat.to_pandas()
+
+    assert (
+        np.array(pyat.column(0))
+        == [
+            np.datetime64("1000-01-01T00:00:00.000000000"),
+            np.datetime64("3000-01-01T00:00:00.000000000"),
+        ]
+    ).all()
+
+
+def test_df2pyarrow_meta():
+    """Test that metadata in summary dataframes dframe.attrs are passed on to
+    pyarrow tables"""
+    dframe = pd.DataFrame(columns=["FOO", "BAR"], data=[[1, 2], [3, 4]]).astype("int32")
+    dframe.attrs["meta"] = {
+        "FOO": {"unit": "barf", "is_interesting": False},
+        "ignoreme": "ignored",
+    }
+    pyat = _df2pyarrow(dframe)
+    assert pyat.select(["FOO"]).schema[0].metadata == {
+        b"unit": b"barf",
+        b"is_interesting": b"False",
+    }
+    assert pyat.select(["BAR"]).schema[0].metadata == {}
+
+    assert "is_interesting" in pyat.schema.to_string()
+    assert "ignored" not in pyat.schema.to_string()
+
+
+def test_df2pyarrow_strings():
+    """Check that dataframes can have string columns passing through PyArrow"""
+    dframe = pd.DataFrame(columns=["FOO", "BAR"], data=[["hei", "hopp"]])
+    pyat_df = _df2pyarrow(dframe).to_pandas()
+    pd.testing.assert_frame_equal(dframe, pyat_df[["FOO", "BAR"]])
+
+
+@pytest.mark.skipif(not HAVE_OPM, reason="Test requires OPM")
+def test_ecl2df_errors(tmp_path):
     """Test error handling on bogus/corrupted summary files"""
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     Path("FOO.UNSMRY").write_bytes(os.urandom(100))
     Path("FOO.SMSPEC").write_bytes(os.urandom(100))
     with pytest.raises(OSError, match="Failed to create summary instance"):
@@ -972,7 +1167,7 @@ def test_df2eclsum_errors():
 
 
 @pytest.mark.integration
-def test_csv2ecl_summary(tmpdir, mocker):
+def test_csv2ecl_summary(tmp_path, mocker):
     """Check that we can call df2eclsum through the csv2ecl command line
     utility"""
     dframe = pd.DataFrame(
@@ -981,7 +1176,7 @@ def test_csv2ecl_summary(tmpdir, mocker):
             {"DATE": "2017-01-01", "FOPT": 1000, "FOPR": 100},
         ]
     )
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     dframe.to_csv("summary.csv")
     mocker.patch(
         "sys.argv",
